export type EOFError = (typeof EOFError)[keyof typeof EOFError];
export declare const EOFError: {
    readonly OutOfBounds: "Trying to read out of bounds";
    readonly VerifyUint: "Uint does not match expected value ";
    readonly VerifyBytes: "Bytes do not match expected value";
    readonly FORMAT: "err: invalid format";
    readonly MAGIC: "err: invalid magic";
    readonly VERSION: "err: invalid eof version";
    readonly KIND_TYPE: "err: expected kind types";
    readonly KIND_CODE: "err: expected kind code";
    readonly KIND_DATA: "err: expected kind data";
    readonly TERMINATOR: "err: expected terminator";
    readonly TypeSize: "missing type size";
    readonly InvalidTypeSize: "err: type section size invalid";
    readonly CodeSize: "missing code size";
    readonly CodeSectionSize: "code section should be at least one byte";
    readonly InvalidCodeSize: "code size does not match type size";
    readonly DataSize: "missing data size";
    readonly ContainerSize: "missing container size";
    readonly ContainerSectionSize: "container section should at least contain one section and at most 255 sections";
    readonly TypeSections: "err: mismatch of code sections count and type signatures";
    readonly Inputs: "expected inputs";
    readonly Outputs: "expected outputs";
    readonly MaxInputs: "inputs exceeds 127, the maximum, got: ";
    readonly MaxOutputs: "outputs exceeds 127, the maximum, got: ";
    readonly Code0Inputs: "first code section should have 0 inputs";
    readonly Code0Outputs: "first code section should have 0x80 (terminating section) outputs";
    readonly MaxStackHeight: "expected maxStackHeight";
    readonly MaxStackHeightLimit: "stack height limit of 1024 exceeded: ";
    readonly MinCodeSections: "should have at least 1 code section";
    readonly MaxCodeSections: "can have at most 1024 code sections";
    readonly CodeSection: "expected a code section";
    readonly DataSection: "Expected data section";
    readonly ContainerSection: "expected a container section";
    readonly ContainerSectionMin: "container section should be at least 1 byte";
    readonly InvalidEOFCreateTarget: "EOFCREATE targets an undefined container";
    readonly InvalidRETURNContractTarget: "RETURNCONTRACT targets an undefined container";
    readonly ContainerDoubleType: "Container is targeted by both EOFCREATE and RETURNCONTRACT";
    readonly UnreachableContainerSections: "Unreachable containers (by both EOFCREATE and RETURNCONTRACT)";
    readonly ContainerTypeError: "Container contains opcodes which this mode (deployment mode / init code / runtime mode) cannot have";
    readonly DanglingBytes: "got dangling bytes in body";
    readonly InvalidOpcode: "invalid opcode";
    readonly InvalidTerminator: "invalid terminating opcode";
    readonly OpcodeIntermediatesOOB: "invalid opcode: intermediates out-of-bounds";
    readonly InvalidRJUMP: "invalid rjump* target";
    readonly InvalidCallTarget: "invalid callf/jumpf target";
    readonly InvalidCALLFReturning: "invalid callf: calls to non-returning function";
    readonly InvalidStackHeight: "invalid stack height";
    readonly InvalidJUMPF: "invalid jumpf target (output count)";
    readonly InvalidReturningSection: "invalid returning code section: section is not returning";
    readonly ReturningNoReturn: "invalid section: section should return but has no RETF/JUMP to return";
    readonly RJUMPVTableSize0: "invalid RJUMPV: table size 0";
    readonly UnreachableCodeSections: "unreachable code sections";
    readonly UnreachableCode: "unreachable code (by forward jumps)";
    readonly DataLoadNOutOfBounds: "DATALOADN reading out of bounds";
    readonly MaxStackHeightViolation: "Max stack height does not match the reported max stack height";
    readonly StackUnderflow: "Stack underflow";
    readonly StackOverflow: "Stack overflow";
    readonly UnstableStack: "Unstable stack (can reach stack under/overflow by jumps)";
    readonly RetfNoReturn: "Trying to return to undefined function";
    readonly ReturnStackOverflow: "Return stack overflow";
    readonly InvalidExtcallTarget: "invalid extcall target: address > 20 bytes";
    readonly InvalidReturnContractDataSize: "invalid RETURNCONTRACT: data size lower than expected";
    readonly InvalidEofFormat: "invalid EOF format";
};
export type SimpleErrors = (typeof SimpleErrors)[keyof typeof SimpleErrors];
export declare const SimpleErrors: {
    readonly minContainerSize: "err: container size less than minimum valid size";
    readonly invalidContainerSize: "err: invalid container size";
    readonly typeSize: "err: type section size invalid";
    readonly code0msh: "err: computed max stack height for code section 0 does not match expect";
    readonly underflow: "err: stack underflow";
    readonly code0IO: "err: input and output of first code section must be 0";
    readonly VerifyUint: "Uint does not match expected value ";
    readonly VerifyBytes: "Bytes do not match expected value";
    readonly TypeSize: "missing type size";
    readonly InvalidTypeSize: "err: type section invalid";
    readonly CodeSize: "missing code size";
    readonly CodeSectionSize: "code section should be at least one byte";
    readonly InvalidCodeSize: "code size does not match type size";
    readonly DataSize: "missing data size";
    readonly TypeSections: "need to have a type section for each code section";
    readonly Inputs: "expected inputs";
    readonly Outputs: "expected outputs";
    readonly MaxInputs: "inputs exceeds 127, the maximum, got: ";
    readonly MaxOutputs: "outputs exceeds 127, the maximum, got: ";
    readonly Code0Inputs: "first code section should have 0 inputs";
    readonly Code0Outputs: "first code section should have 0 outputs";
    readonly MaxStackHeight: "expected maxStackHeight";
    readonly MaxStackHeightLimit: "stack height limit of 1024 exceeded: ";
    readonly MinCodeSections: "should have at least 1 code section";
    readonly MaxCodeSections: "can have at most 1024 code sections";
    readonly CodeSection: "expected a code section";
    readonly DataSection: "Expected data section";
    readonly DanglingBytes: "got dangling bytes in body";
};
export declare function validationErrorMsg(type: EOFError, ...args: any): string;
export declare function validationError(type: EOFError, ...args: any): never;
//# sourceMappingURL=errors.d.ts.map