"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.precompile0d = precompile0d;
const util_1 = require("@ethereumjs/util");
const evm_ts_1 = require("../evm.js");
const exceptions_ts_1 = require("../exceptions.js");
const index_ts_1 = require("./bls12_381/index.js");
const index_ts_2 = require("./index.js");
const util_ts_1 = require("./util.js");
async function precompile0d(opts) {
    const pName = (0, index_ts_2.getPrecompileName)('0e');
    const bls = opts._EVM._bls;
    // note: the gas used is constant; even if the input is incorrect.
    const gasUsed = opts.common.param('bls12381G2AddGas') ?? BigInt(0);
    if (!(0, util_ts_1.gasLimitCheck)(opts, gasUsed, pName)) {
        return (0, evm_ts_1.OOGResult)(opts.gasLimit);
    }
    if (!(0, util_ts_1.equalityLengthCheck)(opts, 512, pName)) {
        return (0, evm_ts_1.EvmErrorResult)(new exceptions_ts_1.EvmError(exceptions_ts_1.ERROR.BLS_12_381_INVALID_INPUT_LENGTH), opts.gasLimit);
    }
    // check if some parts of input are zero bytes.
    const zeroByteRanges = [
        [0, 16],
        [64, 80],
        [128, 144],
        [192, 208],
        [256, 272],
        [320, 336],
        [384, 400],
        [448, 464],
    ];
    if (!(0, index_ts_1.leading16ZeroBytesCheck)(opts, zeroByteRanges, pName)) {
        return (0, evm_ts_1.EvmErrorResult)(new exceptions_ts_1.EvmError(exceptions_ts_1.ERROR.BLS_12_381_POINT_NOT_ON_CURVE), opts.gasLimit);
    }
    // TODO: verify that point is on G2
    let returnValue;
    try {
        returnValue = bls.addG2(opts.data);
    }
    catch (e) {
        return (0, evm_ts_1.EvmErrorResult)(e, opts.gasLimit);
    }
    if (opts._debug !== undefined) {
        opts._debug(`${pName} return value=${(0, util_1.bytesToHex)(returnValue)}`);
    }
    return {
        executionGasUsed: gasUsed,
        returnValue,
    };
}
//# sourceMappingURL=0d-bls12-g2add.js.map